@@ -694,62 +694,31 @@ class Auth:
     #     jwt_token = mk_jwt_token(user["id"], user["email"], self.auth_secret)
     #     _ = await self.db.update("users", "id", user)
     #     return rest_ok({"jwt_token": jwt_token, "user_info": get_user_info(user)})
-    
-    async def change_org(self, request):
-  
-        label2 = "change_org"
 
+    async def change_org(self, request):
+        """Change su org."""
+        label2 = "change_org"
         ##  make sure the jwt user exists
         if not is_numeric(request.user.display_name):
-<<<<<<< Updated upstream
-            log_and_raise_service(self.LOG, label="AUTH", label2=label2,
-                                  msg="USER_NOT_REGISTERED", status_code=400)
-
-        uid = int(request.user.display_name)
-
-        # make sure that users exists and its active
-        user = await self.enforce_find_user({"id": uid}, label2=label2)
-        
-        # check if table user_orgs exists in schema public
-        # exists_val = await self.db.execute(
-        # "SELECT to_regclass('public.user_orgs')",
-        # fetchval=True
-        # )
-        # table_exists = exists_val is not None
-
-
-        # read target org from body
-=======
             log_and_raise_service(self.LOG, label="AUTH", label2=label2, msg="USER_NOT_REGISTERED", status_code=400)
+
         user = await self.db.select_one("users", {"id":safe_int(request.user.display_name)})
         if user is None:
             log_and_raise_service(self.LOG, label="AUTH", label2=label2, msg="USER_NOT_REGISTERED", status_code=400)
->>>>>>> Stashed changes
+        uid = user['id']
         data = await request.json()
-        target_org = oget(data, ["org"])
+        target_org = oget(data, ['org'])
         if target_org is None:
-            log_and_raise_service(self.LOG, label="AUTH", label2=label2,
-                                  msg="ORG_NOT_PROVIDED", status_code=400)
-
+            log_and_raise_service(self.LOG, label="AUTH", label2=label2, msg="ORG_NOT_PROVIDED", status_code=400)
         role = user.get("role")
-        ## if the table dont exist and the user is not su raise
-        # if not table_exists and role != "su":
-        #     log_and_raise_service(self.LOG, label="AUTH", label2=label2,
-        #                         msg="ORG_CHANGE_NOT_ALLOWED", status_code=403)
-        
-
-        # if not su, validate if the target_org is on user_orgs
+        ## if not su check for authorization in user_orgs
         if role != "su":
-            membership = await self.db.select_one("user_orgs", {"user_id": uid, "org_id": target_org})
+            membership = await self.db.select_one("user_orgs", {"user_id":uid, "org_id":target_org})
             if membership is None:
-                log_and_raise_service(self.LOG, label="AUTH", label2=label2,
-                                      msg="NOT_AUTHORIZED_FOR_ORG", status_code=403)
-
+                log_and_raise_service(self.LOG, label="AUTH", label2=label2, msg="NOT_AUTHORIZED_FOR_ORG", status_code=403)
         # update org
         user["org"] = target_org
         await self.db_update("users", "id", user)
-
         # new  token
         jwt_token = mk_jwt_token(user["id"], user["email"], self.auth_secret)
         return rest_ok({"jwt_token": jwt_token, "user_info": get_user_info(user)})
-
